==> check-mk_1.2.6p12.orig.tar.gz: src/mk_inventory.cc <==
// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
//
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
//
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#include <unistd.h>
#include <stdio.h>
#include <sys/stat.h>

#include "mk_inventory.h"

#ifdef CMC
#include <Config.h>
#define MK_INVENTORY_PATH g_config->_mk_inventory_path
#else
extern char g_mk_inventory_path[];
#define MK_INVENTORY_PATH g_mk_inventory_path
#endif

int mk_inventory_last(const char *host)
{
    char path[4096];
    snprintf(path, sizeof(path), "%s/%s", MK_INVENTORY_PATH, host);
    struct stat st;
    if (0 != stat(path, &st))
        return 0;
    else
        return st.st_mtime;
}

int mk_inventory_last_of_all()
{
    // Check_MK Inventory touches the file ".last" after each inventory
    return mk_inventory_last(".last");
}

==> check-mk_1.2.8p16.orig.tar.gz: src/mk_inventory.cc <==
// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
//
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
//
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#include "mk_inventory.h"
#include <stdio.h>
#include <sys/stat.h>

#ifdef CMC
#include <Config.h>
#define MK_INVENTORY_PATH g_config->_mk_inventory_path
#else
extern char g_mk_inventory_path[];
#define MK_INVENTORY_PATH g_mk_inventory_path
#endif

int mk_inventory_last(const char *host) {
    char path[4096];
    snprintf(path, sizeof(path), "%s/%s", MK_INVENTORY_PATH, host);
    struct stat st;
    if (0 != stat(path, &st)) {
        return 0;
    }
    return st.st_mtime;
}

int mk_inventory_last_of_all() {
    // Check_MK Inventory touches the file ".last" after each inventory
    return mk_inventory_last(".last");
}
